Package: LLMR
Title: Interface for Large Language Model APIs in R
Version: 0.8.6
Depends: R (>= 4.1.0)
Authors@R: 
    person("Ali", "Sanaei", , "sanaei@uchicago.edu", role = c("aut", "cre"))
Description: Provides a unified interface to large language models across multiple
  providers. Supports text generation, tidy data workflows, structured output
  with optional JSON Schema validation, XML-like tag extraction, and embeddings.
  Includes chat sessions, consistent error handling, and parallel batch tools.
License: MIT + file LICENSE
Encoding: UTF-8
Imports: httr2 (>= 1.0.0), curl, purrr, dplyr, tidyr, rlang, memoise,
        future, future.apply, tibble, base64enc, mime, glue (>= 1.6.0),
        cli (>= 3.6.0), jsonlite, vctrs, digest
Suggests: testthat (>= 3.0.0), roxygen2 (>= 7.1.2), httptest2,
        progressr, knitr, rmarkdown, ggplot2, R.rsp, jsonvalidate,
        stringi, kableExtra
RoxygenNote: 7.3.3
Config/testthat/edition: 3
URL: https://github.com/asanaei/LLMR, https://asanaei.github.io/LLMR/
BugReports: https://github.com/asanaei/LLMR/issues
VignetteBuilder: knitr
NeedsCompilation: no
Author: Ali Sanaei [aut, cre]
Maintainer: Ali Sanaei <sanaei@uchicago.edu>
Packaged: 2026-06-17 06:01:29 UTC; ali
Repository: CRAN
Date/Publication: 2026-06-17 06:50:02 UTC
Built: R 4.4.3; ; 2026-06-17 09:26:30 UTC; unix
