# Generated by roxygen2: do not edit by hand

S3method(as.character,llmr_response)
S3method(as.data.frame,llm_chat_session)
S3method(call_llm,alibaba)
S3method(call_llm,anthropic)
S3method(call_llm,deepseek)
S3method(call_llm,default)
S3method(call_llm,gemini)
S3method(call_llm,gemini_embedding)
S3method(call_llm,groq)
S3method(call_llm,moonshot)
S3method(call_llm,ollama)
S3method(call_llm,ollama_embedding)
S3method(call_llm,openai)
S3method(call_llm,openai_embedding)
S3method(call_llm,together)
S3method(call_llm,together_embedding)
S3method(call_llm,voyage)
S3method(call_llm,voyage_embedding)
S3method(call_llm,xai)
S3method(call_llm,xiaomi)
S3method(call_llm,zhipu)
S3method(diagnostics,default)
S3method(format,llm_config)
S3method(head,llm_chat_session)
S3method(print,llm_chat_session)
S3method(print,llm_config)
S3method(print,llmr_agreement)
S3method(print,llmr_batch_job)
S3method(print,llmr_preview)
S3method(print,llmr_response)
S3method(print,llmr_tool)
S3method(print,summary.llm_chat_session)
S3method(report,default)
S3method(reset,default)
S3method(summary,llm_chat_session)
S3method(summary,llmr_experiment)
S3method(tail,llm_chat_session)
export(bind_tools)
export(build_factorial_experiments)
export(cache_llm_call)
export(call_llm)
export(call_llm_broadcast)
export(call_llm_compare)
export(call_llm_par)
export(call_llm_par_structured)
export(call_llm_par_tags)
export(call_llm_robust)
export(call_llm_stream)
export(call_llm_sweep)
export(call_llm_tools)
export(chat_session)
export(diagnostics)
export(disable_structured_output)
export(enable_structured_output)
export(expand_llm_config)
export(finish_reason)
export(get_batched_embeddings)
export(is_truncated)
export(llm_agreement)
export(llm_api_key_env)
export(llm_batch_cancel)
export(llm_batch_fetch)
export(llm_batch_status)
export(llm_batch_submit)
export(llm_config)
export(llm_cross_design)
export(llm_failures)
export(llm_fn)
export(llm_fn_structured)
export(llm_fn_tags)
export(llm_hash)
export(llm_judge)
export(llm_log_disable)
export(llm_log_enable)
export(llm_log_read)
export(llm_log_status)
export(llm_logprobs)
export(llm_methods_text)
export(llm_mutate)
export(llm_mutate_structured)
export(llm_mutate_tags)
export(llm_par_resume)
export(llm_parse_rowpack_tags)
export(llm_parse_structured)
export(llm_parse_structured_col)
export(llm_parse_tags)
export(llm_parse_tags_col)
export(llm_preview)
export(llm_render_messages)
export(llm_replicate)
export(llm_request_from_log)
export(llm_request_hash)
export(llm_response_record)
export(llm_tool)
export(llm_usage)
export(llm_validate_structured_col)
export(log_llm_error)
export(parse_embeddings)
export(report)
export(reset)
export(reset_llm_parallel)
export(setup_llm_parallel)
export(tokens)
export(tool_calls)
importFrom(base64enc,base64encode)
importFrom(glue,glue_data)
importFrom(httr2,req_error)
importFrom(httr2,req_perform)
importFrom(httr2,resp_body_json)
importFrom(httr2,resp_body_raw)
importFrom(httr2,resp_header)
importFrom(httr2,resp_status)
importFrom(memoise,memoise)
importFrom(mime,guess_type)
importFrom(purrr,compact)
importFrom(purrr,detect)
importFrom(purrr,keep)
importFrom(purrr,list_transpose)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(rlang,.data)
importFrom(rlang,`%||%`)
importFrom(rlang,`:=`)
importFrom(stats,runif)
importFrom(stats,setNames)
importFrom(utils,head)
importFrom(utils,modifyList)
importFrom(utils,tail)
importFrom(vctrs,vec_c)
importFrom(vctrs,vec_cast)
importFrom(vctrs,vec_ptype_common)
