% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/json_mode.R
\name{call_llm_par_structured}
\alias{call_llm_par_structured}
\title{Parallel experiments with structured parsing}
\usage{
call_llm_par_structured(experiments, schema = NULL, .fields = NULL, ...)
}
\arguments{
\item{experiments}{Tibble with \code{config} and \code{messages} list-columns.}

\item{schema}{Optional JSON Schema list.}

\item{.fields}{Optional fields to hoist from parsed JSON (supports nested paths).}

\item{...}{Passed to \code{\link[=call_llm_par]{call_llm_par()}}.}
}
\description{
Enables structured output on each config (if not already set), runs, then parses JSON.
}
\seealso{
\code{\link[=call_llm_par]{call_llm_par()}}, \code{\link[=llm_parse_structured_col]{llm_parse_structured_col()}},
\code{\link[=enable_structured_output]{enable_structured_output()}}
}
